// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KNOTIFYCONFIG_VERSION_H
#define KNOTIFYCONFIG_VERSION_H

#define KNOTIFYCONFIG_VERSION_STRING "5.90.0"
#define KNOTIFYCONFIG_VERSION_MAJOR 5
#define KNOTIFYCONFIG_VERSION_MINOR 90
#define KNOTIFYCONFIG_VERSION_PATCH 0
#define KNOTIFYCONFIG_VERSION ((5<<16)|(90<<8)|(0))

#endif
